@@ -4,6 +4,7 @@ UI widget classes.
 
 # ----------------------------------------------------------------------------------
 
+from typing import Tuple
 from matplotlib import colors
 from matplotlib import pyplot as plt
 import numpy as np
@@ -29,7 +30,8 @@ class DataArrayImageView(pg.ImageView):
     def __init__(self, parent=None) -> None:
         super(DataArrayImageView, self).__init__(
             parent, 
-            view=pg.PlotItem()
+            view=pg.PlotItem(),
+            image=pg.ImageItem()
         )
 
         self.ui.histogram.hide()
@@ -51,7 +53,7 @@ class DataArrayImageView(pg.ImageView):
             bottom = data_array.dims[0],
             left = data_array.dims[1]
         )
-
+        self._set_axis_coords(data_array)
         self.setImage(image)
 
     # ------------------------------------------------------------------------------
@@ -69,6 +71,34 @@ class DataArrayImageView(pg.ImageView):
 
         return color_image
 
+    # ------------------------------------------------------------------------------
+
+    def _set_axis_coords(self, data_array: xr.DataArray) -> None:
+        """
+        
+        """
+
+        def _is_monotonic(values: list):
+            dx = np.diff(values)
+            return np.all(dx <= 0) or np.all(dx >= 0)
+
+        def _set_rect_values(values: list):
+            if type(values[0]) == str or not _is_monotonic(values):
+                start = 0
+                length = len(values)
+            else:
+                start = values[0]
+                length = values[-1] - values[0]
+            return start, length
+        
+        x_values = data_array.coords[data_array.dims[0]].values
+        y_values = data_array.coords[data_array.dims[1]].values
+
+        x, width = _set_rect_values(x_values)
+        y, height = _set_rect_values(y_values)
+
+        self.imageItem.setOpts(rect=(x, y, width, height))
+
 # ----------------------------------------------------------------------------------
 
 class DataArrayPlot(pg.PlotWidget):
